@@ -743,6 +743,12 @@ class ReportOne:
 
     def for_table(self) -> dict:
         # 장고에서 사용할 eval 테이블을 만들기 위해 각각의 레코드를 구성하는 함수
+
+        corp_eval_db = CorpsEval(self.code)
+        corp_eval_db.set_col('c104q')
+        최근매출액증가율q = corp_eval_db.latest_value('매출액증가율')
+
+        logger.error(self.eval_dict)
         logger.debug(f"code: {self.eval_dict['c101']['코드']}")
         logger.debug(f"PFCF : {self.eval_dict['mil']['가치지표']['PFCF']}")
         logger.debug(f"PCR : {self.eval_dict['mil']['가치지표']['PCR']}")
@@ -758,8 +764,9 @@ class ReportOne:
             '이익지표': utils.to_float(self.eval_dict['mil']['이익지표']),
             'ROIC': utils.to_float(self.eval_dict['mil']['투자수익률']['ROIC']),
             'ROE': utils.to_float(self.eval_dict['mil']['투자수익률']['ROE']),
-            'PFCF': utils.to_float(utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PFCF'])),
-            'PCR': utils.to_float(utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PCR'])),
+            'PFCF': utils.to_float(utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PFCF'])[1]),
+            'PCR': utils.to_float(utils.ext_latest_value(self.eval_dict['mil']['가치지표']['PCR'])[1]),
+            '매출액증가율q': utils.to_float(최근매출액증가율q),
         }
 
 
